/*
 * util.c - Utility functions
 *
 * Written 2001 by Werner Almesberger
 * Copyright 2001 EPFL-ICA, Network Robots
 */


#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <unistd.h>
#include <sys/time.h>

#include "util.h"


/* ---------------------------- Malloc wrappers ---------------------------- */


void *alloc(size_t size)
{
    void *new;

    new = malloc(size);
    if (new) return new;
    perror("malloc");
    exit(1);
}


char *stralloc(const char *s)
{
    char *new;

    new = strdup(s);
    if (new) return new;
    perror("strdup");
    exit(1);
}


/* ---------------- Helper functions for performance tuning ---------------- */


static struct timeval timer;


void start_timer(void)
{
    gettimeofday(&timer,NULL);
}


void print_timer(const char *label)
{
    struct timeval now;

    gettimeofday(&now,NULL);
    now.tv_usec -= timer.tv_usec;
    now.tv_sec -= timer.tv_sec;
    if (now.tv_usec < 0) {
	now.tv_usec += 1000000;
	now.tv_sec--;
    }
    fprintf(stderr,"%s: %d.%06d\n",label,(int) now.tv_sec,(int) now.tv_usec);
}
